@@ -1,6 +1,6 @@
 context("baggr() calls with mu and tau model")
 library(baggr)
-
+library(testthat)
 
 # prepare inputs ----------------------------------------------------------
 set.seed(1990)
@@ -11,7 +11,7 @@ df_mutau <- data.frame("tau" = c(1, -1, .5, -.5, .7, -.7, 1.3, -1.3),
                        "mu" = rnorm(8),
                        "se.mu" = rep(1, 8),
                        "state" = datasets::state.name[1:8])
-
+#
 # tests ----------------------------------------------------------
 test_that("Error messages for wrong inputs are in place", {
   # model, data or pooling mismatch
@@ -30,9 +30,11 @@ test_that("Error messages for wrong inputs are in place", {
   df_na <- df_mutau; df_na$mu <- as.character(df_na$mu)
   expect_error(baggr(df_na),"are not numeric")
 
-  expect_warning(baggr(df_mutau, group = "state1000", iter = 50), "No labels will be added.")
+  expect_warning(baggr(df_mutau, group = "state1000", iter = 50, refresh = 0),
+                 "No labels will be added.")
   expect_identical(names(convert_inputs(df_mutau, "mutau")),
-                   c("K", "P", "tau_hat_k", "se_tau_k", "K_test", "test_tau_hat_k", "test_se_k"))
+                   c("K", "P", "tau_hat_k", "se_tau_k",
+                     "K_test", "test_tau_hat_k", "test_se_k"))
 
 
 
@@ -43,12 +45,13 @@ test_that("We can't run Rubin model with mutau outputs", {
   expect_error(baggr(df_mutau, model = "rubin", iter = 200, refresh = 0))
 })
 
-bg5_n <- baggr(df_mutau, pooling = "none", group = "state",
-               iter = 200, chains = 2, refresh = 0)
-bg5_p <- baggr(df_mutau, pooling = "partial", group = "state",
-               iter = 200, chains = 2, refresh = 0)
-bg5_f <- baggr(df_mutau, pooling = "full", group = "state",
-               iter = 200, chains = 2, refresh = 0)
+bg5_n <- expect_warning(baggr(df_mutau, pooling = "none", group = "state",
+               iter = 200, chains = 2, refresh = 0))
+bg5_p <- expect_warning(baggr(df_mutau, pooling = "partial", group = "state",
+               iter = 200, chains = 2, refresh = 0))
+bg5_f <- expect_warning(baggr(df_mutau, pooling = "full", group = "state",
+               iter = 200, chains = 2, refresh = 0))
+
 test_that("Different pooling methods work for mu tau model", {
   expect_is(bg5_n, "baggr")
   expect_is(bg5_p, "baggr")
@@ -92,7 +95,7 @@ test_that("Pooling metrics", {
   expect_gt(min(pp), 0)
   expect_lt(max(pp), 1)
   # since all SEs are the same, pooling should be the same for all sites
-  print(pp)
+  capture_output(pp)
   # expect_equal(pp[2,,1], .75, tolerance = .1) #YUGE tolerance as we only do 200 iter
   expect_equal(length(unique(pp[2,,1])), 1)
   expect_equal(as.numeric(pp[2,1,1]), .7, tolerance = .2)
@@ -119,13 +122,13 @@ test_that("Plotting works", {
 })
 
 test_that("Test data can be used in the mu tau model", {
-
-  bg_lpd <- baggr(df_mutau[1:6,], test_data = df_mutau[7:8,], iter = 2000, chains = 2, refresh = 0)
+  bg_lpd <- expect_warning(baggr(df_mutau[1:6,], test_data = df_mutau[7:8,],
+                  iter = 2000, chains = 2, refresh = 0))
   expect_is(bg_lpd, "baggr")
   # make sure that we have 6 sites, not 8:
   expect_equal(dim(group_effects(bg_lpd)), c(2000, 6, 1))
   # make sure it's not 0 but something sensible
-  expect_equal(mean(rstan::extract(bg_lpd$fit, "logpd")[[1]]), -13, tolerance = 1)
+  expect_equal(mean(rstan::extract(bg_lpd$fit, "logpd[1]")[[1]]), -13, tolerance = 1)
 
   # wrong test_data
   df_na <- df_mutau[7:8,]; df_na$tau <- NULL
@@ -136,9 +139,10 @@ test_that("Test data can be used in the mu tau model", {
 # test helpers -----
 
 test_that("Extracting treatment/study effects works", {
-  expect_error(treatment_effect(df_mutau), "treatment_effect requires a baggr object")
+  expect_error(treatment_effect(df_mutau))
   expect_is(treatment_effect(bg5_p), "list")
   expect_identical(names(treatment_effect(bg5_p)), c("tau", "sigma_tau"))
   expect_is(treatment_effect(bg5_p)$tau, "numeric")
   expect_message(treatment_effect(bg5_n), "no treatment effect estimated when")
 })
+
